@@ -21,7 +21,7 @@
 /*!
   @file    tags.hpp
   @brief   Exif tag and type information
-  @version $Rev: 1039 $
+  @version $Rev: 1118 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    15-Jan-04, ahu: created<BR>
@@ -118,7 +118,7 @@ namespace Exiv2 {
      */
     struct TagDetails {
         long val_;                              //!< Tag value
-        char* label_;                           //!< Translation of the tag value
+        const char* label_;                     //!< Translation of the tag value
 
         //! Comparison operator for use with the find template
         bool operator==(long key) const { return val_ == key; }
@@ -130,7 +130,7 @@ namespace Exiv2 {
      */
     struct TagDetailsBitmask {
         uint32_t mask_;                         //!< Bitmask value
-        char* label_;                           //!< Description of the tag value
+        const char* label_;                     //!< Description of the tag value
     }; // struct TagDetailsBitmask
 
     /*!
